@@ -7,7 +7,7 @@ def test():
     isNorm = True
     for i in m:
         i = int(i)
-        e, d, n = my_RSA.RSA.get_bit_keys(256) #****************************************
+        e, d, n = my_RSA.RSA.get_bit_keys(256)
         if (pow(pow(i, e, n), d, n)) != i:
             print("error")
             isNorm = False
@@ -16,7 +16,7 @@ def test():
         print("eee i feel good")
 
 
-def main():
+def test_calculating_keys():
     e, d, n = my_RSA.RSA.get_bit_keys(1024)
     m = 'hello world'
     print(n)
@@ -26,6 +26,17 @@ def main():
     print(m)
 
 
+def tmp():
+    # Pypi please let me commit
+    tmp =  2
+    tmp += 1
+    print(tmp)
+    pass
+
+
+def main():
+    test_calculating_keys()
+
 
 if __name__ == '__main__':
     main()
